@@ -407,8 +407,7 @@ class Machine(MachineBase):
         """
         self._apt("install -yq nginx libnginx-mod-rtmp")
         self.nginx_conf = "/etc/nginx/nginx.conf"
-        # XXX self.web_data = "/var/www"
-        self.open_ports(80, 443)
+        self.open_ports(80, 443, 1935)
         streaming_dir = "/home/gaea/media/streaming"
         self.run(f"mkdir {streaming_dir} -p")
         self.run(f"mkdir {streaming_dir}/hls")
